@@ -1,131 +1,222 @@
 #' Read Template
 #'
-#' Reads file either from template name in system folder, file path or remote URL, and splits it into lines for easier handling by \emph{rapport} internal parser. "find" in \code{tpl.find} is borrowed from Emacs parlance - this function actually reads the template.
+#' Reads file either from template name in system folder, file path (see \code{rapport.path}) or remote URL, and splits it into lines for easier handling by \emph{rapport} internal parser.
 #' @param fp a character string containing a template path, a template name (for package-bundled templates only), template contents separated by newline (\code{\\n}), or a character vector with template contents.
+#' @param ... additional params for header tag matching (see \code{\link{grep}})
 #' @return a character vector with template contents
-tpl.find <- function(fp){
+#' @aliases rapport.read tpl.find
+rapport.read <- function(fp, ...) {
+
     if (missing(fp))
-        stop('file pointer not provided')
+        stop('Template file pointer not provided!')
     stopifnot(is.character(fp))
+
     l <- length(fp)
+
     ## maybe it's file path?
-    if (l == 1){
+    if (l == 1) {
+
         ## is it URL?
         if (grepl('^(ftp|http(s)?)://.+$', fp)) {
             if (download.file(fp, tmp.fp <- tempfile(), method = 'wget') != 0)
-                stop('remote file not found')
+                stop('Remote template file not found!')
             file <- tmp.fp
         } else {
-            ## is it local file found in working, package or custom \code{getOption('tpl.paths')} directory?
-            if (!grepl('.+\\.tpl$', fp, ignore.case = TRUE))
-                fp <- c(fp, sprintf('%s.tpl', fp))
-            fp <- c(fp, unlist(lapply(fp, function(file) file.path(getOption('tpl.paths'), file))), system.file('templates', fp, package = 'rapport'))
+
+            ## is it local file found in working, package or custom \code{getOption('rapport.paths')} directory?
+            if (!grepl('.+\\.rapport$', fp, ignore.case = TRUE))
+                fp <- c(fp, sprintf('%s.rapport', fp))
+            fp <- c(fp, unlist(lapply(fp, function(file) file.path(getOption('rapport.paths'), file))), system.file('templates', fp, package = 'rapport'))
             fp <- fp[file.exists(fp)]
             if (length(fp) == 0)
-                stop('File not found!')
+                stop('Template file not found!')
             if (length(fp) > 1) {
                 fp <- fp[1]
                 warning(sprintf('Multiple templates found with given name, using: %s', fp))
             }
         }
-        txt <- readLines(fp, warn = FALSE) # load template from file path
-    } else if (l > 1){
+        txt <- readLines(fp, warn = FALSE, encoding = 'UTF-8') # load template from file path
+    } else if (l > 1) {
         ## then it's a character vector
-        con <- textConnection(fp)
-        txt <- readLines(con, warn = FALSE)
-        close(con)
+        txt <- fp
     } else {
-        stop('file pointer error')      # you never know...
+        stop('Template file pointer error :O')      # you never know...
     }
+
+    check.tpl(txt, ...)
     return(txt)
+
 }
+tpl.find <- rapport.read
+
+
+##' Extract template chunk contents
+##'
+##' \code{rapport}'s alternative to \code{\link{Stangle}} - extracts contents of template chunks. If \code{file} argument
+##' @param fp template file pointer (see \code{rapport:::rapport.read} for details)
+##' @param file see \code{file} argument in \code{\link{cat}} function documentation
+##' @param show.inline.chunks extract contents of inline chunks as well? (defaults to \code{FALSE})
+##' @return (invisibly) a list with either inline or block chunk contents
+##' @export
+##' @aliases rapport.tangle tpl.tangle
+rapport.tangle <- function(fp, file = "", show.inline.chunks = FALSE) {
+
+    b <- rapport.body(rapport.read(fp))
+
+    re.block.open    <- "^<%=?$"
+    re.block.close   <- "^%>$"
+    re.inline.open   <- "<%=?"
+    re.inline.close  <- "%>"
+
+    ind.block.open   <- grep(re.block.open, b)
+    ind.block.close  <- grep(re.block.close, b)
+    ind.inline.open  <- grep(re.inline.open, b)
+    ind.inline.close <- grep(re.inline.close, b)
+
+    ## check for unmatched tags
+    if (show.inline.chunks) {
+        if (length(ind.inline.open) != length(ind.inline.close))
+            stop("unmatched chunk tag(s)")
+    } else {
+        if (length(ind.block.open) != length(ind.block.close))
+            stop("unmatched block chunk tag(s)")
+    }
+
+    block.ind <- mapply(seq, from = ind.block.open, to = ind.block.close)
+    if (show.inline.chunks)
+        chunk.ind <- mapply(seq, from = ind.inline.open, to = ind.inline.close)
+    else
+        chunk.ind <- block.ind
+
+    chunk.ind <- lapply(chunk.ind, function(x) {
+        attr(x, "chunk.type") <- "block"
+        x
+    })
+
+    if (show.inline.chunks) {
+        chunk.ind[!chunk.ind %in% block.ind] <- lapply(chunk.ind[!chunk.ind %in% block.ind], function(x) {
+            attr(x, "chunk.type") <- "inline"
+            x
+        })
+    }
+
+    out <- c()
+    res <- lapply(chunk.ind, function(x) {
+        cc <- b[x]
+        ct <- attr(x, "chunk.type")
+        if (ct == "block") {
+            cc <- trim.space(paste0(cc[2:(length(cc) - 1)], collapse = "\n"))
+            out <<- c(out, "#################")
+            out <<- c(out, "## block chunk ##")
+            out <<- c(out, "#################")
+            out <<- c(out, "", cc, "")
+        } else {
+            cc <- trim.space(vgsub("(<%=?|%>)", "", str_extract_all(cc, "<%=?[^%>]+%>")[[1]]))
+            sapply(cc, function(x) {
+                out <<- c(out, "##################")
+                out <<- c(out, "## inline chunk ##")
+                out <<- c(out, "##################")
+                out <<- c(out, "", x, "")
+            })
+        }
+        attr(cc, "chunk.type") <- ct
+        cc
+    })
+
+    out <- paste0(out, collapse = "\n")
+    cat(out, file = file)
+
+    invisible(res)
+}
+#' @export
+tpl.tangle <- rapport.tangle
 
 
 #' Template Header
 #'
 #' Returns \code{rapport} template header from provided path or a character vector.
-#' @param fp a template file pointer (see \code{\link{tpl.find}} for details)
+#' @param fp a template file pointer (see \code{rapport:::rapport.read} for details)
 #' @param open.tag a string with opening tag (defaults to value of user-defined \code{"header.open"} tag)
 #' @param close.tag a string with closing tag (defaults to value of user-defined \code{"header.close"} tag)
 #' @param ... additional arguments to be passed to \code{\link{grep}} function
 #' @return a character vector with template header contents
-tpl.header <- function(fp, open.tag = get.tags('header.open'), close.tag = get.tags('header.close'), ...){
-    txt <- tpl.find(fp)                 # split by newlines
+#' @aliases rapport.header tpl.header
+rapport.header <- function(fp, open.tag = get.tags('header.open'), close.tag = get.tags('header.close'), ...) {
+
+    txt <- rapport.read(fp)                 # split by newlines
 
     ## get header tag indices
-    hopen.ind  <- grep(open.tag, txt, ...)  # opening tag
-    hclose.ind <- grep(close.tag, txt, ...) # closing tag
-
-    ## check header indices
-    if (hopen.ind != 1)
-        stop('opening header tag not found in first line')
-
-    ## only ONE header tag pairs required
-    if (!(length(hopen.ind) == 1 & length(hclose.ind) == 1))
-        stop('header tag error')
-
+    hopen.ind  <- grep(open.tag, txt, ...)[1]  # opening tag
+    hclose.ind <- grep(close.tag, txt, ...)[1] # closing tag
     hsection <- txt[(hopen.ind + 1):(hclose.ind - 1)] # get header
 
-    if (
-        length(hsection) < 1            # blank header
-        |
-        all(grepl('^[[:space:]]+$', hsection)) # only whitespace
-        |
-        all(nchar(hsection) == 0)       # only newlines
-        )
-        stop('template header empty')
-
     return(hsection)
 }
+#' @export
+tpl.header <- rapport.header
 
 
 #' Template Body
 #'
 #' Returns contents of the template body.
-#' @param fp a template file pointer (see \code{\link{tpl.find}} for details)
+#' @param fp a template file pointer (see \code{rapport:::rapport.read} for details)
 #' @param htag a string with closing body tag
 #' @param ... additional arguments to be passed to \code{\link{grep}} function
 #' @return a character vector with template body contents
 #' @export
-tpl.body <- function(fp, htag = get.tags('header.close'), ...){
-    txt   <- tpl.find(fp)
+#' @aliases rapport.body tpl.body
+rapport.body <- function(fp, htag = get.tags('header.close'), ...) {
+    txt   <- rapport.read(fp, ...)
     h.end <- grep(htag, txt, ...)
-    if (h.end == length(txt))
-        structure('', class = 'rp.body')
-    else
-        structure(txt[(h.end + 1):length(txt)], class = 'rp.body')
+    b <- txt[(h.end + 1):length(txt)]
+    structure(b, class = 'rapport.body')
 }
+#' @export
+tpl.body <- rapport.body
 
 
 #' Template Info
 #'
-#' Provides information about template metadata and/or inputs. See \code{\link{tpl.meta}} and \code{\link{tpl.inputs}} for details.
-#' @param fp a template file pointer (see \code{\link{tpl.find}} for details)
+#' Provides information about template metadata and/or inputs. See \code{\link{rapport.meta}} and \code{\link{rapport.inputs}} for details.
+#' @param fp a template file pointer (see \code{rapport:::rapport.read} for details)
 #' @param meta return template metadata? (defaults to \code{TRUE})
 #' @param inputs return template inputs? (defaults to \code{TRUE})
 #' @examples \dontrun{
-#' tpl.info('example')  # return both metadata and inputs
-#' tpl.info('crosstable', inputs = FALSE)  # return only template metadata
-#' tpl.info('correlations', meta = FALSE)  # return only template inputs
+#' rapport.info('Example')                    # return both metadata and inputs
+#' rapport.info('Crosstable', inputs = FALSE) # return only template metadata
+#' rapport.info('Correlation', meta = FALSE)  # return only template inputs
+#' }
+#' @seealso {
+#' \code{\link{rapport.meta}}
+#' \code{\link{rapport.inputs}}
 #' }
 #' @export
-tpl.info <- function(fp, meta = TRUE, inputs = TRUE){
-    h <- tpl.header(fp)
+#' @aliases rapport.info tpl.info
+rapport.info <- function(fp, meta = TRUE, inputs = TRUE) {
+
+    txt <- rapport.read(fp)
+
     if (!meta & !inputs)
         stop('Either "meta" or "inputs" should be set to TRUE')
+
     res <- list()
     if (meta)
-        res$meta <- tpl.meta(h, use.header = TRUE)
+        res$meta <- rapport.meta(txt)
     if (inputs)
-        res$inputs <- tpl.inputs(h, use.header = TRUE)
-    class(res) <- 'rp.info'
+        res$inputs <- rapport.inputs(txt)
+    class(res) <- 'rapport.info'
+
     return(res)
 }
+#' @export
+tpl.info <- rapport.info
 
 
 #' Header Metadata
 #'
-#' Displays summary of template metadata stored in a header section. This part of template header consists of several YAML \code{key: value} pairs, which contain some basic information about the template, just much like the \code{DESCRIPTION} file in \code{R} packages does. Current implementation supports following fields:
+#' Displays summary of template metadata stored in a header section. This part of template header consists of several YAML \code{key: value} pairs, which contain some basic information about the template, just much like the \code{DESCRIPTION} file in \code{R} packages does.
+#'
+#' Current implementation supports following fields:
 #'
 #' \itemize{
 #'     \item \code{title} - a template title (required)
@@ -137,18 +228,22 @@ tpl.info <- function(fp, meta = TRUE, inputs = TRUE){
 #' }
 #'
 #' As of version \code{0.5}, \code{dataRequired} field is deprecated. \code{rapport} function will automatically detect if the template requires a dataset based on the presence of \emph{standalone} inputs.
-#' @param fp a template file pointer (see \code{\link{tpl.find}} for details)
+#' @param fp a template file pointer (see \code{rapport:::rapport.read} for details)
 #' @param fields a list of named lists containing key-value pairs of field titles and corresponding regexes
-#' @param use.header a logical value indicating if the character vector provided in \code{fp} argument contains only header data and not the whole template
+#' @param use.header a logical value indicating if the character vector provided in \code{fp} argument contains only the header data (not the whole template)
 #' @param trim.white a logical value indicating if the extra spaces should removed from header fields before extraction
 #' @return a named list with template metadata
+#' @seealso {
+#' \code{\link{rapport.inputs}}
+#' \code{\link{rapport.info}}
+#' }
 #' @export
-tpl.meta <- function(fp, fields = NULL, use.header = FALSE, trim.white = TRUE) {
-
-    header <- tpl.find(fp)
+#' @aliases rapport.meta tpl.meta
+rapport.meta <- function(fp, fields = NULL, use.header = FALSE, trim.white = TRUE) {
 
+    header <- rapport.read(fp)
     if (!use.header)
-        header <- tpl.header(header)
+        header <- rapport.header(header)
 
     ## check if header is defined in YAML
     h <- tryCatch({
@@ -186,7 +281,7 @@ tpl.meta <- function(fp, fields = NULL, use.header = FALSE, trim.white = TRUE) {
             )
 
         ## no fields specified, load default fields
-        if (!is.null(fields)){
+        if (!is.null(fields)) {
             fld.title <- sapply(fld, function(x) x$title)
             fields.title  <- sapply(fields, function(x) x$title)
             fld <- c(fld, fields) # merge required fields with default/specified ones
@@ -202,7 +297,7 @@ tpl.meta <- function(fp, fields = NULL, use.header = FALSE, trim.white = TRUE) {
         if (length(rm.ind) > 0)
             header <- header[-rm.ind]
 
-        h <- sapply(fld, function(x){
+        h <- sapply(fld, function(x) {
             m <- grep(sprintf("^%s:", x$title), header)
             x$x <- header[m]
             do.call(extract.meta, x)
@@ -215,7 +310,7 @@ tpl.meta <- function(fp, fields = NULL, use.header = FALSE, trim.white = TRUE) {
 
         ## examples
         ## TODO: change to "examples" at some point (easy does it)
-        if (!is.null(h$example)){
+        if (!is.null(h$example)) {
             ## select all "untagged" lines after Example: that contain rapport(<smth>) string
             ## but it will not check if they're syntactically correct
             ind.start <- grep('^Example:', header)
@@ -250,8 +345,10 @@ tpl.meta <- function(fp, fields = NULL, use.header = FALSE, trim.white = TRUE) {
     if (length(unsupported.meta))
         warningf('Unsupported metadata field(s) found: %s', p(unsupported.meta, wrap = "\""))
 
-    structure(h, class = 'rp.meta')
+    structure(h, class = 'rapport.meta')
 }
+#' @export
+tpl.meta <- rapport.meta
 
 
 #' Template Inputs
@@ -311,15 +408,20 @@ tpl.meta <- function(fp, fields = NULL, use.header = FALSE, trim.white = TRUE) {
 #'     \item \code{nlevels} - accepts the same format as \code{length} attribute, but the check is performed rather on the number of factor levels.
 #'     \item \code{matchable} - \emph{ibid} as in character inputs (note that in previous versions of \code{rapport} matching was performed against factor levels - well, not any more, now we match against values to make it consistent with \code{character} inputs).
 #' }
-#' @param fp a template file pointer (see \code{\link{tpl.find}} for details)
+#' @param fp a template file pointer (see \code{rapport:::rapport.read} for details)
 #' @param use.header a logical value indicating whether the header section is provided in \code{h} argument
+#' @seealso {
+#' \code{\link{rapport.meta}}
+#' \code{\link{rapport.info}}
+#' }
 #' @export
-tpl.inputs <- function(fp, use.header = FALSE){
+#' @aliases rapport.inputs tpl.inputs
+rapport.inputs <- function(fp, use.header = FALSE) {
 
-    header <- tpl.find(fp)
+    header <- rapport.read(fp)
 
     if (!use.header)
-        header <- tpl.header(header)
+        header <- rapport.header(header)
 
     ## Try with YAML first ("inputs" is actually decoded header)
     inputs <- tryCatch(
@@ -346,14 +448,14 @@ tpl.inputs <- function(fp, use.header = FALSE){
         inputs.ind <- grep("^(.+\\|){3}.+$", header) # get input definition indices
 
         if (length(inputs.ind) == 0)
-            return (structure(NULL, class = 'rp.inputs'))
+            return (structure(NULL, class = 'rapport.inputs'))
 
         inputs.raw <- lapply(strsplit(header[inputs.ind], '|', fixed = TRUE), function(x) trim.space(x)) # "raw" as in "unchecked", split by | and trimmed for whitespace
 
         if (!all(sapply(inputs.raw, length) == 4))
             stop('input definition error: missing fields')
 
-        inputs <- lapply(inputs.raw, function(x){
+        inputs <- lapply(inputs.raw, function(x) {
             i.name  <- guess.input.name(x[1])
             i.label <- guess.input.label(x[3])
             i.desc  <- guess.input.description(x[4])
@@ -371,7 +473,7 @@ tpl.inputs <- function(fp, use.header = FALSE){
                 i.type
                 )
         })
-        warning("Oh, no! This template has outdated input definition! You can update it by running `tpl.renew`.")
+        warning("Oh, no! This template has outdated input definition! You can update it by running `rapport.renew`.")
     } else {
         inputs <- lapply(inputs$inputs, guess.input)
     }
@@ -382,38 +484,41 @@ tpl.inputs <- function(fp, use.header = FALSE){
     if (any(dupes))
         stopf('template contains duplicate input names: %s', p(nms[dupes], wrap = "\""))
 
-    structure(inputs, class = 'rp.inputs')
+    structure(inputs, class = 'rapport.inputs')
 }
+#' @export
+tpl.inputs <- rapport.inputs
 
 
 #' Template Examples
 #'
-#' Displays template examples defined in \code{Example} section. Handy to check out what template does and how does it look like once it's rendered. If multiple examples are available, and \code{index} argument is \code{NULL}, you will be prompted for input. If only one example is available in the header, user is not prompted for input action, and given template is evaluated automatically. At any time you can provide an integer vector with example indices to \code{index} argument, and specified examples will be evaluated without prompting, thus returning a list of \code{rapport} objects. Example output can be easily exported to various formats (HTML, ODT, etc.) - check out documentation for \code{tpl.export} for more info.
-#' @param fp a template file pointer (see \code{\link{tpl.find}} for details)
+#' Displays template examples defined in \code{Example} section. Handy to check out what template does and how does it look like once it's rendered. If multiple examples are available, and \code{index} argument is \code{NULL}, you will be prompted for input. If only one example is available in the header, user is not prompted for input action, and given template is evaluated automatically. At any time you can provide an integer vector with example indices to \code{index} argument, and specified examples will be evaluated without prompting, thus returning a list of \code{rapport} objects. Example output can be easily exported to various formats (HTML, ODT, etc.) - check out documentation for \code{rapport.export} for more info.
+#' @param fp a template file pointer (see \code{rapport:::rapport.read} for details)
 #' @param index a numeric vector indicating the example index - meaningful only for templates with multiple examples. Accepts vector of integers to match IDs of template example. Using 'all' (character string) as index will return all examples.
 #' @param env an environment where example will be evaluated (defaults to \code{.GlobalEnv})
 #' @examples \dontrun{
-#' tpl.example('example')
-#' tpl.example('example', 1:2)
-#' tpl.example('example', 'all')
-#' tpl.example('crosstable')
-#' tpl.export(tpl.example('crosstable'))
+#' rapport.example('Example')
+#' rapport.example('Example', 1:2)
+#' rapport.example('Example', 'all')
+#' rapport.example('Crosstable')
+#' rapport.export(rapport.example('Crosstable'))
 #' }
 #' @export
-tpl.example <- function(fp, index = NULL, env = .GlobalEnv) {
+#' @aliases rapport.example tpl.example
+rapport.example <- function(fp, index = NULL, env = .GlobalEnv) {
 
-    examples   <- tpl.meta(fp)$example
+    examples   <- rapport.meta(fp)$example
     n.examples <- 1:length(examples)
     examples.len <- length(examples)
 
     ## return NULL invisibly if no templates are found in the template
-    if (is.null(examples)){
+    if (is.null(examples)) {
         message('Provided template does not have any examples.')
         invisible(NULL)
     }
 
-    if (examples.len > 1){
-        if (is.null(index)){
+    if (examples.len > 1) {
+        if (is.null(index)) {
             opts  <- c(n.examples)
             catn('Enter example ID from the list below:')
             catn(sprintf('\n(%s)\t%s', opts, c(examples)))
@@ -445,6 +550,8 @@ tpl.example <- function(fp, index = NULL, env = .GlobalEnv) {
     else
         eval(parse(text = examples[index]), envir = env)
 }
+#' @export
+tpl.example <- rapport.example
 
 
 #' Reproduce Template
@@ -452,11 +559,12 @@ tpl.example <- function(fp, index = NULL, env = .GlobalEnv) {
 #' Runs template with data and arguments included in \code{rapport} object. In order to get reproducible example, you have to make sure that \code{reproducible} argument is set to \code{TRUE} in \code{rapport} function.
 #' @param tpl a \code{rapport} object
 #' @examples \dontrun{
-#' tmp <- rapport("example", mtcars, x = "hp", y = "mpg", reproducible = TRUE)
-#' tpl.rerun(tmp)
+#' tmp <- rapport("Example", mtcars, v = "hp", reproducible = TRUE)
+#' rapport.rerun(tmp)
 #' }
 #' @export
-tpl.rerun <- function(tpl){
+#' @aliases rapport.rerun tpl.rerun
+rapport.rerun <- function(tpl) {
 
     if (!inherits(tpl, 'rapport'))
         stop("You haven't provided a rapport template")
@@ -471,24 +579,26 @@ tpl.rerun <- function(tpl){
     cl$data <- dt
     do.call(rapport, cl)
 }
+#' @export
+tpl.rerun <- rapport.rerun
 
 
 #' Evaluate Template
 #'
-#' This is the central function in the \code{rapport} package, and hence eponymous. In following lines we'll use \code{rapport} to denote the function, not the package. \code{rapport} requires a template file, while dataset (\code{data} argument) can be optional, depending on the value of \code{Data required} field in template header. Template inputs are matched with \code{...} argument, and should be provided in \code{x = value} format, where \code{x} matches input name and \code{value}, wait for it... input value! See \code{\link{tpl.inputs}} for more details on template inputs.
+#' This is the central function in the \code{rapport} package, and hence eponymous. In following lines we'll use \code{rapport} to denote the function, not the package. \code{rapport} requires a template file, while dataset (\code{data} argument) can be optional, depending on the value of \code{Data required} field in template header. Template inputs are matched with \code{...} argument, and should be provided in \code{x = value} format, where \code{x} matches input name and \code{value}, wait for it... input value! See \code{\link{rapport.inputs}} for more details on template inputs.
 #'
 #' Default parameters are read from \code{evalsOptions()} and the following \code{options}:
 #'
 #' \itemize{
-#'     \item 'rp.file.name',
-#'     \item 'rp.file.path',
+#'     \item 'rapport.file.name',
+#'     \item 'rapport.file.path',
 #' }
 #'
-#' @param fp a template file pointer (see \code{\link{tpl.find}} for details)
+#' @param fp a template file pointer (see \code{rapport:::rapport.read} for details)
 #' @param data a \code{data.frame} to be used in template
 #' @param ... matches template inputs in format 'key = "value"'
-#' @param env an environment where template commands be evaluated (defaults to \code{new.env()}
-#' @param reproducible a logical value indicating if the call and data should be stored in template object, thus making it reproducible (see \code{\link{tpl.rerun}} for details)
+#' @param env the parent environment to be forked, in which temporary \code{new.env} template commands be evaluated
+#' @param reproducible a logical value indicating if the call and data should be stored in template object, thus making it reproducible (see \code{\link{rapport.rerun}} for details)
 #' @param header.levels.offset number added to header levels (handy when using nested templates)
 #' @param file.name set the file name of saved plots and exported documents. A simple character string might be provided where \code{\%N} would be replaced by an auto-increment integer based on similar exported document's file name , \code{\%n} an auto-increment integer based on similar (plot) file names (see: \code{?evalsOptions}), \code{\%T} by the name of the template in action and \code{\%t} by some uniqe random characters based on \code{\link{tempfile}}.
 #' @param file.path path of a directory where to store generated images and exported reports
@@ -501,49 +611,72 @@ tpl.rerun <- function(tpl){
 #' @return a list with \code{rapport} class.
 #' @seealso \code{\link{rapport-package}}
 #' @examples \dontrun{
-#' rapport("example", ius2008, var = "leisure")
-#' rapport("example", ius2008, var = "leisure", desc = FALSE, hist = TRUE, theme = "Set1")
+#' rapport('Example', ius2008, v = "leisure")
+#' rapport('Descriptives', ius2008, var = "leisure")
 #'
 #' ## generating high resolution images also
-#' rapport("example", ius2008, var="leisure", hist = TRUE, graph.hi.res = TRUE)
-#' rapport.html("nortest", ius2008, var = "leisure", graph.hi.res=T)
+#' rapport('Example', ius2008, v = "leisure", graph.hi.res = TRUE)
+#' rapport.html('NormalityTest', ius2008, var = "leisure", graph.hi.res=T)
 #' ## generating only high resolution image
-#' rapport("example", ius2008, var="leisure", hist = TRUE, graph.width = 1280, graph.height = 1280)
+#' rapport('Example', ius2008, v = "leisure", graph.width = 1280, graph.height = 1280)
 #' ## nested templates cannot get custom setting, use custom rapport option:
 #' options('graph.hi.res' = TRUE)
-#' rapport('descriptives-multivar', data=ius2008, vars=c("gender", 'age'))
+#' rapport('AnalyzeWizard', data=ius2008, variables=c('edu', 'game'))
 #' }
 #' @export
-rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE, header.levels.offset = 0, graph.output = evalsOptions('graph.output'), file.name = getOption('rp.file.name'), file.path = getOption('rp.file.path'), graph.width = evalsOptions('width'), graph.height = evalsOptions('height'), graph.res = evalsOptions('res'), graph.hi.res = evalsOptions('hi.res'), graph.replay = evalsOptions('graph.recordplot')) {
+rapport <- function(fp, data = NULL, ..., env = .GlobalEnv, reproducible = FALSE, header.levels.offset = 0, graph.output = evalsOptions('graph.output'), file.name = getOption('rapport.file.name'), file.path = getOption('rapport.file.path'), graph.width = evalsOptions('width'), graph.height = evalsOptions('height'), graph.res = evalsOptions('res'), graph.hi.res = evalsOptions('hi.res'), graph.replay = evalsOptions('rapport.graph.recordplot')) {
 
-    timer    <- proc.time()                       # start timer
-    txt      <- tpl.find(fp)                      # split file to text
-    h        <- tpl.info(txt)                     # template header
-    meta     <- h$meta                            # header metadata
-    inputs   <- h$inputs                          # header inputs
-    b        <- tpl.body(txt)                     # template body
-    e        <- new.env(parent = env)             # load/create evaluation environment
-    i        <- list(...)                         # user inputs
-    data.required <- any(sapply(inputs, function(x) !x$standalone))
-    pkgs     <- meta$packages                                # required packages
-    file.path <- gsub('\\', '/', file.path, fixed = TRUE)
+    timer         <- proc.time()                        # start timer
+    txt           <- rapport.read(fp)                   # split file to text
+    h             <- rapport.info(txt)                  # template header
+    meta          <- h$meta                             # header metadata
+    inputs        <- h$inputs                           # header inputs
+    inputs.names  <- sapply(inputs, function(x) x$name) # input names
+    b             <- rapport.body(txt)                  # template body
+    e             <- new.env(parent = env)              # load/create evaluation environment
+    e$Pandoc.brew <- Pandoc.brew                        # inject brew function
+    i             <- list(...)                          # user inputs
+    i.names       <- names(i)                           # user input names
+    data.required <- any(sapply(inputs, function(x) !x$standalone)) || (!is.null(data) && !identical(data, ''))
+
+    ## dealing with packages
+    oldpkgs       <- .packages()                        # currently loaded packages to revert later
+    pkgs          <- meta$packages                      # required packages
+
+    ## path issue on Windows
+    file.path     <- gsub('\\', '/', file.path, fixed = TRUE)
 
     ## load required packages (if any)
-    if (!is.null(pkgs)){
-        pk <- suppressMessages(sapply(pkgs, require, character.only = TRUE, quietly = TRUE))
+    if (!is.null(pkgs)) {
+
+        pk <- suppressWarnings(suppressMessages(sapply(pkgs, require, character.only = TRUE, quietly = TRUE)))
+
+        ## unload packages that were loaded on demand
+        on.exit(sapply(setdiff(.packages(), oldpkgs), function(pkg) try(
+            detach(paste('package', pkg, sep = ':'),
+                   character.only = TRUE), silent = TRUE)))
+
+        ## checking for errors
         nopkg <- pk == FALSE
         if (any(nopkg))
-            stopf('Following packages are required by the template, but were not loaded: %s', p(names(pk[nopkg]), wrap = '"'))
+            stop(sprintf('Following packages are required by the template, but were not loaded: %s', p(names(pk[nopkg]), wrap = '"')), call. = NULL)
+
     }
 
+    ## assign template metadata and inputs to custom environment for easy access inside of the templates
+    assign('rapport.inputs', inputs, envir = e)
+    assign('rapport.template', meta, envir = e)
+
     ## template contains no inputs
     if (length(inputs) == 0) {
         ## check if data is required
         if (data.required) {
             if (is.null(data))
                 stop('"data" argument is required by the template')
-            else
+            else {
                 assign('rp.data', data, envir = e)
+                assign('rapport.data', data, envir = e)
+            }
         }
         ## inputs required, carry on...
     } else {
@@ -551,22 +684,23 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
         ## this is silly!!! what if you have input = NULL?!?
         input.required <- sapply(inputs, function(x) structure(x$required, .Names = x$name))
         input.names    <- names(input.required)
-        input.ok       <- input.names[input.required] %in% names(i)
         ## take default inputs into account
-        if (!all(input.ok))
+        if (!all(input.names[input.required] %in% names(i)) && any(sapply(inputs, function(x) is.empty(x$value) & !identical(x$value, FALSE) & is.empty(i[[x$name]]) & x$required))) {
             stopf("you haven't provided a value for %s", p(input.names[input.required], '"'))
+        }
 
         ## data required
-        if (data.required){
+        if (data.required) {
             if(is.null(data))
                 stop('"data" not provided, but is required')
             if (!inherits(data, c('data.frame', 'rp.data')))
                 stop('"data" should be a "data.frame" object')
             data.names <- names(data)          # variable names
             assign('rp.data', data, envir = e) # load data to eval environment
+            assign('rapport.data', data, envir = e)
         }
 
-        lapply(inputs, function(x){
+        lapply(inputs, function(x) {
             ## template inputs
             input.name   <- x$name
             input.class  <- x$class
@@ -607,7 +741,7 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
                     if (!all(user.input %in% data.names))
                         stopf('provided data.frame does not contain column(s) named: %s', p(setdiff(user.input, data.names), '"'))
 
-                    val <- e$rp.data[user.input]
+                    val <- e$rapport.data[user.input]
                     ## we use this as data.frame with 0 columns will not be NULL
                     ## therefore the length check will not pass
                     ## OR we can just change the check.input.value function
@@ -660,33 +794,39 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
 
                 ## add labels
                 if (is.recursive(val)) {
-                    for (t in names(val)){
-                        if (rp.label(val[, t]) == 't')
+                    for (t in names(val)) {
+                        if (label(val[, t]) == 't')
                             val[, t] <- structure(val[, t], label = t, name = t)
                         else
                             val[, t] <- structure(val[, t], name = t)
                     }
                 } else {
-                    if (rp.label(val) == 'val')
+                    if (label(val) == 'val')
                         val <- structure(val, label = user.input, name = user.input)
                     else
                         val <- structure(val, name = user.input)
                 }
             }
 
+            input.exists <- (!input.name %in% i.names && !x$required && x$standalone && length(val)) || input.name %in% i.names || !x$standalone || length(val)
+
             ## assign stuff
-            assign(input.name, val, envir = e)                                    # value
-            assign(sprintf('%s.iname', input.name), input.name, envir = e)        # input name
-            assign(sprintf('%s.ilen', input.name), length(user.input), envir = e) # input length
-            assign(sprintf('%s.ilabel', input.name), x$label, envir = e)          # input label
-            assign(sprintf('%s.idesc', input.name), x$description, envir = e)     # input description
-            assign(sprintf('%s.name', input.name), user.input, envir = e)         # variable name(s)
-            assign(sprintf('%s.len', input.name), length(val), envir = e)         # variable length
+            if (input.exists) {
+                ## assign input value and that silly input-related stuff
+                assign(input.name, val, envir = e)                                    # value
+                assign(sprintf('%s.iname', input.name), input.name, envir = e)        # input name
+                assign(sprintf('%s.ilen', input.name), length(user.input), envir = e) # input length
+                assign(sprintf('%s.ilabel', input.name), x$label, envir = e)          # input label
+                assign(sprintf('%s.idesc', input.name), x$description, envir = e)     # input description
+                assign(sprintf('%s.name', input.name), user.input, envir = e)         # variable name(s)
+                assign(sprintf('%s.len', input.name), length(val), envir = e)         # variable length
+            }
+
             ## currently we support only data.frame and atomic vectos
             if (is.data.frame(val))
-                assign(sprintf('%s.label', input.name), sapply(val, rp.label), envir = e) # variable labels
+                assign(sprintf('%s.label', input.name), sapply(val, label), envir = e) # variable labels
             else if (is.atomic(val))
-                assign(sprintf('%s.label', input.name), rp.label(val), envir = e) # variable label
+                assign(sprintf('%s.label', input.name), label(val), envir = e) # variable label
             else
                 stopf('"%s" is not a "data.frame" or an atomic vector', input.name) # you never know...
         })
@@ -694,7 +834,8 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
 
     ## pregenerate file name
     if (grepl('%T', file.name))
-        file.name <- gsub('%T', gsub('\\\\|/', '-', fp), file.name, fixed = TRUE)
+        file.name <- gsub('%T', gsub('\\\\|/|:|\\.', '-', fp), file.name, fixed = TRUE)
+    file.name <- gsub('--', '-', file.name, fixed = TRUE)
     if (grepl('%N', file.name)) {
         if (length(strsplit(sprintf('placeholder%splaceholder', file.name), '%N')[[1]]) > 2)
             stop('File name contains more then 1 "%N"!')
@@ -713,7 +854,7 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
     wd.bak   <- getwd()
     setwd(file.path)
     evalsOptions('graph.name', file.name)
-    assign('rp.body', paste(b, collapse = '\n'), envir = e)
+    assign('.rapport.body', paste(b, collapse = '\n'), envir = e)
     assign('.graph.name', file.name, envir = e)
     assign('.graph.dir', evalsOptions('graph.dir'), envir = e)
     assign('.graph.hi.res', graph.hi.res, envir = e)
@@ -721,7 +862,7 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
         assign('.tmpout', 'NUL', envir = e)
     else
         assign('.tmpout', '/dev/null', envir = e)
-    report <- tryCatch(eval(parse(text = 'Pandoc.brew(text = rp.body, graph.name = .graph.name, graph.dir = .graph.dir, graph.hi.res = .graph.hi.res, output = .tmpout)'), envir = e), error = function(e) e)
+    report <- tryCatch(eval(parse(text = 'Pandoc.brew(text = .rapport.body, graph.name = .graph.name, graph.dir = .graph.dir, graph.hi.res = .graph.hi.res, output = .tmpout)'), envir = e), error = function(e) e)
 
     options(opts.bak)                          # resetting options
     setwd(wd.bak)
@@ -731,7 +872,7 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
         stop(report$message)
 
     ## remove NULL/blank parts
-    ## ind.nullblank <- sapply(report, function(x){
+    ## ind.nullblank <- sapply(report, function(x) {
     ##     if (x$type == 'block')
     ##         ifelse(is.null(x$robjects[[1]]$output), FALSE, TRUE)
     ##     else
@@ -740,14 +881,14 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
     ## report <- report[ind.nullblank]     # update template body contents
 
     ## tidy up (removing metadata, inputs from) nested templates
-    report <- unlist(lapply(report, function(x){
+    report <- unlist(lapply(report, function(x) {
 
         robj  <- x$robject
         rout  <- robj$result
         xtype <- x$type
 
         ## chunk holding a rapport class
-        if (xtype == 'block'){
+        if (xtype == 'block') {
 
             if (any(robj$type == 'rapport'))
                 return(rout$report)
@@ -780,7 +921,7 @@ rapport <- function(fp, data = NULL, ..., env = new.env(), reproducible = FALSE,
         file.name   = file.path(file.path, file.name)
         )
 
-    if (isTRUE(reproducible)){
+    if (isTRUE(reproducible)) {
         res$data <- data
     }
 
